@@ -450,6 +450,9 @@ containerEdits:
 	}
 
 	for _, tc := range testCases {
+		// Apply overrides for all test cases:
+		tc.options.nvidiaCDIHookPath = "/usr/bin/nvidia-cdi-hook"
+
 		t.Run(tc.description, func(t *testing.T) {
 			c := command{
 				logger: logger,
