@@ -43,12 +43,42 @@ func TestConfigureLifecycle(t *testing.T) {
 		assertConditions   func(*testing.T, string) error
 	}{
 		// Containerd v2 test cases
+		{
+			description: "containerd: config exists with imports",
+			args: []string{
+				"--runtime", "containerd",
+				"--config", "{{ .testRoot }}/etc/containerd/config.toml",
+				"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
+			},
+			prepareEnvironment: func(t *testing.T, testRoot string) error {
+				configPath := filepath.Join(testRoot, "etc/containerd/config.toml")
+				require.NoError(t, os.MkdirAll(filepath.Dir(configPath), 0755))
+
+				initialConfig := `version = 2
+imports = ["/foo/bar/*.toml"]
+`
+				return os.WriteFile(configPath, []byte(initialConfig), 0600)
+			},
+			assertConditions: func(t *testing.T, testRoot string) error {
+				mainConfig := filepath.Join(testRoot, "etc/containerd/config.toml")
+				content, err := os.ReadFile(mainConfig)
+				require.NoError(t, err)
+
+				expectedTemplate := `imports = ["/foo/bar/*.toml", "{{ .testRoot }}/etc/containerd/conf.d/*.toml"]
+version = 2
+`
+				expected := strings.ReplaceAll(expectedTemplate, "{{ .testRoot }}", testRoot)
+
+				require.Equal(t, expected, string(content))
+				return nil
+			},
+		},
 		{
 			description: "containerd: v2 config does not exist with drop-in",
 			args: []string{
 				"--runtime", "containerd",
 				"--config", "{{ .testRoot }}/etc/containerd/config.toml",
-				"--drop-in-config", "{{ .testRoot }}/etc/containerd/config.d/99-nvidia.toml",
+				"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
 			},
 			assertConditions: func(t *testing.T, testRoot string) error {
 				// Verify main config was created with imports
@@ -61,7 +91,7 @@ func TestConfigureLifecycle(t *testing.T) {
 				require.Contains(t, string(content), "version = 2")
 
 				// Verify drop-in was created
-				dropIn := filepath.Join(testRoot, "etc/containerd/config.d/99-nvidia.toml")
+				dropIn := filepath.Join(testRoot, "etc/containerd/conf.d/99-nvidia.toml")
 				require.FileExists(t, dropIn)
 
 				dropInContent, err := os.ReadFile(dropIn)
@@ -77,7 +107,7 @@ func TestConfigureLifecycle(t *testing.T) {
 			args: []string{
 				"--runtime", "containerd",
 				"--config", "{{ .testRoot }}/etc/containerd/config.toml",
-				"--drop-in-config", "{{ .testRoot }}/etc/containerd/config.d/99-nvidia.toml",
+				"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
 				"--nvidia-set-as-default",
 			},
 			prepareEnvironment: func(t *testing.T, testRoot string) error {
@@ -108,7 +138,7 @@ func TestConfigureLifecycle(t *testing.T) {
 				require.Contains(t, string(content), "imports")
 
 				// Verify drop-in was created with nvidia as default
-				dropIn := filepath.Join(testRoot, "etc/containerd/config.d/99-nvidia.toml")
+				dropIn := filepath.Join(testRoot, "etc/containerd/conf.d/99-nvidia.toml")
 				require.FileExists(t, dropIn)
 
 				dropInContent, err := os.ReadFile(dropIn)
@@ -128,7 +158,7 @@ func TestConfigureLifecycle(t *testing.T) {
 						args: []string{
 							"--runtime", "containerd",
 							"--config", "{{ .testRoot }}/etc/containerd/config.toml",
-							"--drop-in-config", "{{ .testRoot }}/etc/containerd/config.d/99-nvidia.toml",
+							"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
 						},
 						prepareEnvironment: func(t *testing.T, testRoot string) error {
 							configPath := filepath.Join(testRoot, "etc/containerd/config.toml")
@@ -162,11 +192,11 @@ func TestConfigureLifecycle(t *testing.T) {
 			args: []string{
 				"--runtime", "containerd",
 				"--config", "{{ .testRoot }}/etc/containerd/config.toml",
-				"--drop-in-config", "{{ .testRoot }}/etc/containerd/config.d/99-nvidia.toml",
+				"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
 				"--cdi.enabled",
 			},
 			assertConditions: func(t *testing.T, testRoot string) error {
-				dropIn := filepath.Join(testRoot, "etc/containerd/config.d/99-nvidia.toml")
+				dropIn := filepath.Join(testRoot, "etc/containerd/conf.d/99-nvidia.toml")
 				content, err := os.ReadFile(dropIn)
 				require.NoError(t, err)
 				require.Contains(t, string(content), "enable_cdi = true")
@@ -178,12 +208,12 @@ func TestConfigureLifecycle(t *testing.T) {
 			args: []string{
 				"--runtime", "containerd",
 				"--config", "{{ .testRoot }}/etc/containerd/config.toml",
-				"--drop-in-config", "{{ .testRoot }}/etc/containerd/config.d/99-nvidia.toml",
+				"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
 				"--nvidia-runtime-name", "gpu",
 				"--nvidia-runtime-path", "/custom/path/nvidia-container-runtime",
 			},
 			assertConditions: func(t *testing.T, testRoot string) error {
-				dropIn := filepath.Join(testRoot, "etc/containerd/config.d/99-nvidia.toml")
+				dropIn := filepath.Join(testRoot, "etc/containerd/conf.d/99-nvidia.toml")
 				content, err := os.ReadFile(dropIn)
 				require.NoError(t, err)
 				require.Contains(t, string(content), "[plugins.\"io.containerd.grpc.v1.cri\".containerd.runtimes.gpu]")
@@ -400,14 +430,14 @@ runtime_type = "oci"
 				"--dry-run",
 				"--runtime", "containerd",
 				"--config", "{{ .testRoot }}/etc/containerd/config.toml",
-				"--drop-in-config", "{{ .testRoot }}/etc/containerd/config.d/99-nvidia.toml",
+				"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
 			},
 			assertConditions: func(t *testing.T, testRoot string) error {
 				// Verify no files were created
 				mainConfig := filepath.Join(testRoot, "etc/containerd/config.toml")
 				require.NoFileExists(t, mainConfig)
 
-				dropIn := filepath.Join(testRoot, "etc/containerd/config.d/99-nvidia.toml")
+				dropIn := filepath.Join(testRoot, "etc/containerd/conf.d/99-nvidia.toml")
 				require.NoFileExists(t, dropIn)
 
 				return nil
@@ -512,7 +542,7 @@ func TestConfigureCommandLineSource(t *testing.T) {
 				"--config-source", "command",
 				"--executable-path", "{{ .testRoot }}/bin/containerd",
 				"--config", "{{ .testRoot }}/etc/containerd/config.toml",
-				"--drop-in-config", "{{ .testRoot }}/etc/containerd/config.d/99-nvidia.toml",
+				"--drop-in-config", "{{ .testRoot }}/etc/containerd/conf.d/99-nvidia.toml",
 			},
 			prepareEnvironment: func(t *testing.T, testRoot string) error {
 				// Create a mock containerd executable that outputs config
@@ -551,7 +581,7 @@ fi
 			},
 			assertConditions: func(t *testing.T, testRoot string) error {
 				// Should create drop-in with nvidia runtime
-				dropIn := filepath.Join(testRoot, "etc/containerd/config.d/99-nvidia.toml")
+				dropIn := filepath.Join(testRoot, "etc/containerd/conf.d/99-nvidia.toml")
 				require.FileExists(t, dropIn)
 
 				content, err := os.ReadFile(dropIn)
